==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/petitions/lang/petitions_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Vous allez supprimer toutes les signatures de cette p&eacute;tition. &Ecirc;tes-vous sur de vouloir continuer ?', # NEW
	'aucune_signature' => 'Aucune signature', # NEW

	// B
	'bouton_checkbox_envoi_message' => 'possibilit&eacute; d\'envoyer un message', # NEW
	'bouton_checkbox_indiquer_site' => 'indiquer obligatoirement un site web', # NEW
	'bouton_checkbox_signature_unique_email' => 'une seule signature par adresse email', # NEW
	'bouton_checkbox_signature_unique_site' => 'une seule signature par site web', # NEW

	// F
	'filtre' => 'Filtre :', # NEW
	'form_pet_adresse_site' => 'Endereço do seu site', # MODIF
	'form_pet_aucune_signature' => 'Nenhuma assinatura corresponde a este código...',
	'form_pet_confirmation' => 'Por favor, confirme a sua assinatura:',
	'form_pet_deja_signe' => 'Você já assinou este texto.',
	'form_pet_envoi_mail_confirmation' => 'Um e-mail de confirmação acabou de ser enviado para @email@. Você deverá visitar o endereço web mencionado na mensagem para validar a sua assinatura.', # MODIF
	'form_pet_mail_confirmation' => 'Bom dia,

Você pediu para assinar a petição:
@titre@.

Você forneceu as informações abaixo:
    Nome: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@

IMPORTANTE...
Para validar a sua assinatura, basta se conectar ao
endereço abaixo (caso contrário, seu pedido será
rejeitado):

    @url@


Obrigado por participar
',
	'form_pet_message_commentaire' => 'Uma mensagem ou comentário?', # MODIF
	'form_pet_nom_site2' => 'Nome do seu website', # MODIF
	'form_pet_probleme_liens' => 'Por favor, retire os links hipertexto da sua mensagem.',
	'form_pet_probleme_technique' => 'Problema técnico: as assinaturas estão suspensas temporariamente.',
	'form_pet_signature_validee' => 'Sua assinatura foi validada. Obrigado!',
	'form_pet_site_deja_enregistre' => 'Este site já está cadastrado',
	'form_pet_url_invalide' => 'O URL que você informou não é válido.',
	'form_pet_votre_email' => 'Seu endereço de e-mail',
	'form_pet_votre_nom' => 'Seu nome ou apelido', # MODIF
	'form_pet_votre_site' => 'Se você tem um website, você pode informá-lo abaixo',

	// I
	'icone_relancer_signataire' => 'Relancer le signataire', # NEW
	'icone_relancer_signataires' => 'Relancer les signataires', # NEW
	'icone_suivi_petitions' => 'Suivre/g&eacute;rer les p&eacute;titions', # NEW
	'icone_supprimer_signature' => 'Supprimer cette signature', # NEW
	'icone_supprimer_signatures' => 'Supprimer les signatures', # NEW
	'icone_valider_signature' => 'Valider cette signature', # NEW
	'icone_valider_signatures' => 'Valider les signatures', # NEW
	'info_adresse_email' => 'ENDEREÇO DE E-MAIL:',
	'info_fonctionnement_petition' => 'Fonctionnement de la p&eacute;tition :', # NEW
	'info_signature_supprimee' => 'Assinatura excluída',
	'info_signature_supprimee_erreur' => 'Erro: este código de exclusão não corresponde a nenhuma assinatura',
	'info_site_web' => 'WEBSITE:',
	'info_texte_message' => 'Texto da sua mensagem:',

	// L
	'lien_reponse_article' => 'Resposta à matéria',

	// N
	'nombre_signatures' => '@nb@ signatures', # NEW

	// S
	'sans_nom' => 'Anonyme', # NEW
	'signatures_article' => 'Signatures de l\'article :', # NEW
	'signatures_aucune' => 'Aucune', # NEW
	'signatures_meme_auteur' => 'Les signatures du m', # NEW
	'signatures_meme_site' => 'Les signatures avec le m', # NEW
	'signatures_poubelle' => 'Supprim&eacute;es', # NEW
	'signatures_prop' => 'En attente', # NEW
	'signatures_publie' => 'Confirm&eacute;es', # NEW
	'signatures_recherche_label' => 'Rechercher des signatures&nbsp;:', # NEW
	'signatures_toutes' => 'Toutes', # NEW
	'statut_poubelle' => 'Supprim&eacute;e', # NEW
	'statut_prop' => 'En attente de validation', # NEW
	'statut_publie' => 'Confirm&eacute;e', # NEW

	// T
	'texte_descriptif_petition' => 'Descriptif de la p&eacute;tition', # NEW
	'titre_page_controle_petition' => 'Suivi des p&eacute;titions', # NEW
	'titre_petition' => 'P&eacute;tition', # NEW
	'titre_petitions' => 'P&eacute;titions', # NEW
	'titre_selection_action' => 'Sélection', # NEW
	'titre_signatures_attente' => 'Signatures en attente de validation', # NEW
	'titre_signatures_publie' => 'Signatures confirm&eacute;es', # NEW
	'titre_suivi_petition' => 'Suivi des p&eacute;titions', # NEW
	'tout_voir' => 'Voir toutes les signatures', # NEW

	// U
	'une_signature' => '1 signature', # NEW

	// V
	'voir_signatures_objet' => 'Voir les signatures' # NEW
);

?>

==> spip_3.1~21100.orig.tar.xz: spip-3.1~21100.orig/plugins-dist/petitions/lang/petitions_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Ativar a petição',
	'bouton_radio_pas_petition' => 'Sem petição',
	'bouton_radio_petition_activee' => 'Petição ativada',
	'bouton_radio_supprimer_petition' => 'Excluir a petição',

	// F
	'form_pet_adresse_site' => 'Endereço do seu site', # MODIF
	'form_pet_aucune_signature' => 'Nenhuma assinatura corresponde a este código...', # MODIF
	'form_pet_confirmation' => 'Por favor, confirme a sua assinatura:',
	'form_pet_deja_signe' => 'Você já assinou este texto.',
	'form_pet_envoi_mail_confirmation' => 'Um e-mail de confirmação acabou de ser enviado para @email@. Você deverá visitar o endereço web mencionado na mensagem para validar a sua assinatura.', # MODIF
	'form_pet_mail_confirmation' => 'Bom dia,

Você pediu para assinar a petição:
@titre@.

Você forneceu as informações abaixo:
    Nome: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@

IMPORTANTE...
Para validar a sua assinatura, basta se conectar ao
endereço abaixo (caso contrário, seu pedido será
rejeitado):

    @url@


Obrigado por participar
',
	'form_pet_nom_site2' => 'Nome do seu website', # MODIF
	'form_pet_probleme_liens' => 'Por favor, retire os links hipertexto da sua mensagem.',
	'form_pet_probleme_technique' => 'Problema técnico: as assinaturas estão suspensas temporariamente.',
	'form_pet_signature_validee' => 'Sua assinatura foi validada. Obrigado!',
	'form_pet_site_deja_enregistre' => 'Este site já está cadastrado',
	'form_pet_url_invalide' => 'O URL que você informou não é válido.',
	'form_pet_votre_email' => 'Seu endereço de e-mail',
	'form_pet_votre_nom' => 'Seu nome ou apelido', # MODIF
	'form_pet_votre_site' => 'Se você tem um website, você pode informá-lo abaixo',

	// I
	'info_adresse_email' => 'ENDEREÇO DE E-MAIL:',
	'info_signature_supprimee' => 'Assinatura excluída',
	'info_signature_supprimee_erreur' => 'Erro: este código de exclusão não corresponde a nenhuma assinatura', # MODIF
	'info_site_web' => 'WEBSITE:',

	// L
	'lien_reponse_article' => 'Resposta à matéria'
);

?>
